@@ -1,6 +1,6 @@
 /* Remote File-I/O communications
 
-   Copyright (C) 2003-2022 Free Software Foundation, Inc.
+   Copyright (C) 2003-2025 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -19,8 +19,9 @@
 
 /* See the GDB User Guide for details of the GDB remote protocol.  */
 
-#include "defs.h"
-#include "gdbcmd.h"
+#include "event-top.h"
+#include "extract-store-integer.h"
+#include "cli/cli-cmds.h"
 #include "remote.h"
 #include "gdbsupport/gdb_wait.h"
 #include <sys/stat.h>
@@ -33,7 +34,7 @@
 #include <fcntl.h>
 #include "gdbsupport/gdb_sys_time.h"
 #ifdef __CYGWIN__
-#include <sys/cygwin.h>		/* For cygwin_conv_path.  */
+#include <sys/cygwin.h>
 #endif
 #include <signal.h>
 
@@ -316,7 +317,7 @@ static void
 remote_fileio_reply (remote_target *remote, int retcode, int error)
 {
   char buf[32];
-  int ctrl_c = check_quit_flag ();
+  bool ctrl_c = check_quit_flag ();
 
   strcpy (buf, "F");
   if (retcode < 0)
@@ -554,7 +555,7 @@ remote_fileio_func_read (remote_target *remote, char *buf)
 	break;
       default:
 	buffer = (gdb_byte *) xmalloc (length);
-	/* POSIX defines EINTR behaviour of read in a weird way.  It's allowed
+	/* POSIX defines EINTR behavior of read in a weird way.  It's allowed
 	   for read() to return -1 even if "some" bytes have been read.  It
 	   has been corrected in SUSv2 but that doesn't help us much...
 	   Therefore a complete solution must check how many bytes have been
@@ -623,7 +624,7 @@ remote_fileio_func_write (remote_target *remote, char *buf)
       return;
     }
   length = (size_t) num;
-    
+
   buffer = (gdb_byte *) xmalloc (length);
   if (target_read_memory (ptrval, buffer, length) != 0)
     {
@@ -640,7 +641,7 @@ remote_fileio_func_write (remote_target *remote, char *buf)
 	return;
       case FIO_FD_CONSOLE_OUT:
 	{
-	  ui_file *file = target_fd == 1 ? gdb_stdtarg : gdb_stdtargerr;
+	  ui_file *file = gdb_stdtarg;
 	  file->write ((char *) buffer, length);
 	  file->flush ();
 	  ret = length;
@@ -706,7 +707,7 @@ remote_fileio_func_lseek (remote_target *remote, char *buf)
       remote_fileio_reply (remote, -1, FILEIO_EINVAL);
       return;
     }
-  
+
   ret = lseek (fd, offset, flag);
 
   if (ret == (off_t) -1)
@@ -730,14 +731,14 @@ remote_fileio_func_rename (remote_target *remote, char *buf)
       remote_fileio_ioerror (remote);
       return;
     }
-  
+
   /* 2. Parameter: Ptr to newpath / length incl. trailing zero */
   if (remote_fileio_extract_ptr_w_len (&buf, &new_ptr, &new_len))
     {
       remote_fileio_ioerror (remote);
       return;
     }
-  
+
   /* Request oldpath using 'm' packet */
   oldpath = (char *) alloca (old_len);
   if (target_read_memory (old_ptr, (gdb_byte *) oldpath, old_len) != 0)
@@ -745,7 +746,7 @@ remote_fileio_func_rename (remote_target *remote, char *buf)
       remote_fileio_ioerror (remote);
       return;
     }
-  
+
   /* Request newpath using 'm' packet */
   newpath = (char *) alloca (new_len);
   if (target_read_memory (new_ptr, (gdb_byte *) newpath, new_len) != 0)
@@ -753,7 +754,7 @@ remote_fileio_func_rename (remote_target *remote, char *buf)
       remote_fileio_ioerror (remote);
       return;
     }
-  
+
   /* Only operate on regular files and directories.  */
   of = stat (oldpath, &ost);
   nf = stat (newpath, &nst);
@@ -871,7 +872,7 @@ remote_fileio_func_stat (remote_target *remote, char *buf)
       return;
     }
   statptr = (CORE_ADDR) lnum;
-  
+
   /* Request pathname using 'm' packet */
   pathname = (char *) alloca (namelength);
   if (target_read_memory (nameptr, (gdb_byte *) pathname, namelength) != 0)
@@ -1077,7 +1078,7 @@ remote_fileio_func_system (remote_target *remote, char *buf)
 	  return;
 	}
     }
-  
+
   /* Check if system(3) has been explicitly allowed using the
      `set remote system-call-allowed 1' command.  If length is 0,
      indicating a NULL parameter to the system call, return zero to
@@ -1191,12 +1192,17 @@ remote_fileio_request (remote_target *remote, char *buf, int ctrlc_pending_p)
 	{
 	  do_remote_fileio_request (remote, buf);
 	}
+      catch (const gdb_exception_forced_quit &ex)
+	{
+	  throw;
+	}
+      catch (const gdb_exception_quit &ex)
+	{
+	  remote_fileio_reply (remote, -1, FILEIO_EINTR);
+	}
       catch (const gdb_exception &ex)
 	{
-	  if (ex.reason == RETURN_QUIT)
-	    remote_fileio_reply (remote, -1, FILEIO_EINTR);
-	  else
-	    remote_fileio_reply (remote, -1, FILEIO_EIO);
+	  remote_fileio_reply (remote, -1, FILEIO_EIO);
 	}
     }
 
